<?php
/** Nepali (नेपाली)
 *
 * @ingroup Language
 * @file
 *
 * @author ne.wikipedia.org sysops
 */

$digitTransformTable = array(
	'0' => '०', # &#x0966;
	'1' => '१', # &#x0967;
	'2' => '२', # &#x0968;
	'3' => '३', # &#x0969;
	'4' => '४', # &#x096a;
	'5' => '५', # &#x096b;
	'6' => '६', # &#x096c;
	'7' => '७', # &#x096d;
	'8' => '८', # &#x096e;
	'9' => '९', # &#x096f;
);

$messages = array(
# Dates
'sunday'        => 'आईतबार',
'monday'        => 'सोमबार',
'tuesday'       => 'मंगलबार',
'wednesday'     => 'बुधबार',
'thursday'      => 'बिहीबार',
'friday'        => 'शुक्रबार',
'saturday'      => 'शनिबार',
'wed'           => 'वुध',
'january'       => 'जेनवरी',
'february'      => 'फेब्रुअरी',
'march'         => 'मार्च',
'april'         => 'एप्रील',
'may_long'      => 'मे',
'june'          => 'जुन',
'july'          => 'जुलाई',
'august'        => 'अगस्त',
'september'     => 'सेप्टेम्बर',
'october'       => 'अक्टोबर',
'november'      => 'नोभेम्बर',
'december'      => 'डिसेम्बर',
'january-gen'   => 'जेनवरी',
'february-gen'  => 'फेब्रुअरी',
'march-gen'     => 'मार्च',
'april-gen'     => 'एप्रील',
'may-gen'       => 'मे',
'june-gen'      => 'जुन',
'july-gen'      => 'जुलाई',
'august-gen'    => 'अगस्त',
'september-gen' => 'सेप्टेम्बर',
'october-gen'   => 'अक्टोबर',
'november-gen'  => 'नोभेम्बर',
'december-gen'  => 'डिसेम्बर',
'may'           => 'मे',
'nov'           => 'नोभ',

# Categories related messages
'category_header' => '"$1" श्रेणीमा भएका लेखहरू',
'subcategories'   => 'उपश्रेणीहरु',

'about'         => 'बारेमा',
'article'       => 'मुख्य-लेख पृष्ठ',
'newwindow'     => '(नयाँ विन्डोमा खुल्छ)',
'cancel'        => 'रद्द',
'qbfind'        => 'पत्ता लगाउनु',
'qbbrowse'      => 'खोज',
'qbedit'        => 'परिवर्तन्',
'qbpageoptions' => 'यो पेज',
'qbmyoptions'   => 'मेरो पेज',
'moredotdotdot' => 'थप...',
'mypage'        => 'मेरो पृष्ठ',
'mytalk'        => 'मेरो कुरा',
'anontalk'      => 'यस् IP को वारेमा वार्तालाप गर्नुहोस्',
'navigation'    => 'अन्वेषण',
'and'           => '&#32;र',

'help'             => 'सहयोग',
'search'           => 'खोज',
'searchbutton'     => 'खोज',
'go'               => 'जाउ',
'searcharticle'    => 'जाउ',
'history'          => 'पृष्ठको इतिहास',
'history_short'    => 'पृष्ठको इतिहास',
'info_short'       => 'जानकारी',
'printableversion' => 'छाप्नमिल्ने संस्करण',
'permalink'        => 'स्थायी लिंक',
'print'            => 'प्रिन्ट (छाप्नुस)',
'edit'             => 'परिवर्तन',
'editthispage'     => 'यो पृष्ठ सम्पादन गर्नुहोस्',
'delete'           => 'मेट्नुहोस्',
'protect'          => 'सुरक्षित राख्नुहोस्',
'newpage'          => 'नयाँ पृष्ठ',
'talkpage'         => 'यो पृष्ठको बारेमा छलफल गर्नुहोस्',
'personaltools'    => 'व्यक्तिगत औजारहरू',
'postcomment'      => 'कमेन्ट पोस्ट गर्नुहोस',
'articlepage'      => 'कन्टेन्ट पृष्ठ हेर्नुहोस्',
'talk'             => 'वार्तालाप',
'toolbox'          => 'औजारबट्टा',
'imagepage'        => 'चित्रको पृष्ठ हेर्नुहोस्',
'otherlanguages'   => 'अरु भाषामा',
'redirectedfrom'   => '($1 बाट पठाईएको)',
'lastmodifiedat'   => 'यो पृष्ठलाई अन्तिमपटक $2, $1 मा परिवर्तन गरिएको थियो।', # $1 date, $2 time
'protectedpage'    => 'सुरक्षित गरिएका पृष्ठहरू',
'jumptonavigation' => 'अन्वेषण',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutpage'            => 'Project:बारेमा',
'copyright'            => 'लेखका सामाग्री $1 अनुसार उपलब्ध छ।',
'currentevents'        => 'हालैका घटनाहरु',
'currentevents-url'    => 'Project:हालैका घटनाहरु',
'edithelp'             => 'सम्पादन सहायता',
'mainpage'             => 'मुख्य पृष्ठ',
'mainpage-description' => 'मुख्य पृष्ठ',
'portal'               => 'सामाजिक पोर्टल',
'portal-url'           => 'Project:सामाजिक पोर्टल',
'privacy'              => 'गोपनियता नीति',

'badaccess'        => 'आज्ञा त्रुटी',
'badaccess-group0' => 'तपाईले अनुरोध गर्नुभएको कार्य गर्न तपाईलाई अनुमति दिइएको छैन।',

'ok'                      => 'हुन्छ',
'youhavenewmessages'      => 'तपाइको लागि ($2) मा  $1 छ ।',
'newmessageslink'         => 'नयाँ सन्देशहरू',
'newmessagesdifflink'     => 'आखिरी परिवर्तन',
'youhavenewmessagesmulti' => 'तपाईंको लागि $1 मा  नयाँ सन्देशहरू छन्',
'editsection'             => 'परिवर्तन्',
'editold'                 => 'परिवर्तन्',
'editsectionhint'         => 'खण्ड: $1 सम्पादन गर्नुहोस्',
'toc'                     => 'विषयसूची',
'showtoc'                 => 'देखाउनु',
'hidetoc'                 => 'लुकाउनुहोस्',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'लेख',
'nstab-user'      => 'प्रयोगकर्ता पृष्ठ',
'nstab-media'     => 'माध्यम पृष्ठ',
'nstab-special'   => 'विशेष',
'nstab-project'   => 'आयोजना पृष्ठ',
'nstab-image'     => 'फाईल',
'nstab-mediawiki' => 'सन्देश',
'nstab-template'  => 'ढाँचा (टेम्प्लेट)',
'nstab-help'      => 'सहायता पृष्ठ',
'nstab-category'  => 'श्रेणी',

# Main script and global functions
'nosuchaction'      => 'यस्तो कार्य हैन',
'nosuchspecialpage' => 'त्यस्तो विषेश पृष्ठ छैन',

# General errors
'badarticleerror' => 'यो कार्य यस पृष्ठमा गर्न मिल्दैन।',
'badtitle'        => 'गलत शिर्षक',
'perfcached'      => 'तलको डाटाहरु क्याचमा रहेका कुराहरु हुन्। अपटुडेट नहुनपनि सक्छन्।',
'perfcachedts'    => 'तलको डाटाहरु क्याचमा रहेका कुराहरु हुन् र यो पछिल्लो पल्ट $1 मा अपडेट गरीएको थियो ।',

# Login and logout pages
'welcomecreation'            => '== तपाँईलाई स्वागत छ $1! ==
तपाँईको खाता खोलिएको छ। {{SITENAME}}का आफ्ना अभिरुचिहरू परिवर्तन गर्न नबिर्सिनुहोला।',
'loginpagetitle'             => 'प्रयोगकर्ता प्रवेश',
'yourname'                   => 'प्रयोगकर्ता-नाम',
'yourpassword'               => 'पासवर्ड',
'yourpasswordagain'          => 'पासवर्ड फेरी टाईप गर्नुहोस्',
'yourdomainname'             => 'तपाइको कार्यक्षेत्र(डोमेन)',
'login'                      => 'प्रवेश (लग ईन)',
'userlogin'                  => 'प्रवेश / खाता खोल्नुहोस्',
'logout'                     => 'निर्गमन (लग आउउ)',
'userlogout'                 => 'निर्गमन (लग आउउ)',
'notloggedin'                => 'प्रवेश (लग ईन) नगरिएको',
'nologinlink'                => 'नयाँ खाता खोल्नुहोस्',
'createaccount'              => 'खाता खोल्नुहोस्',
'gotaccountlink'             => 'लग इन',
'badretype'                  => 'तपाईंले दिनुभएको पासवर्ड मिल्दैन।',
'youremail'                  => 'ईमेल',
'yourrealname'               => 'वास्तविक नाम:',
'yourlanguage'               => 'भाषा:',
'yourvariant'                => 'परिवर्तित प्रकार',
'yournick'                   => 'उपनाम (निकनेम):',
'email'                      => 'ईमेल',
'noname'                     => 'तपाईले सहि युजर नेम उल्लेख गर्नु भएन.',
'nouserspecified'            => 'तपाँईले प्रयोगकर्तानाम (युजरनेम) जनाउनुपर्छ।',
'wrongpassword'              => 'पासवर्ड गलत हालियो । कृपया फेरी प्रयास गर्नुहोला ।',
'wrongpasswordempty'         => 'तपाइले हालेको पासवर्ड खालि थियो । कृपया फेरी प्रयास गर्नुहोला ।',
'mailmypassword'             => 'मेरो पासवर्ड ईमेल गरिदिनुहोस्',
'acct_creation_throttle_hit' => 'माफ गर्नुहोला तपाइले पहिलेनै $1 वटा खाताहरु खोलिसक्नुभएको छ। तपाइले अब अरु बनाउन सक्नुहुन्न।',
'emailconfirmlink'           => 'तपाईंको ई-मेल ठेगाना कन्फर्म गर्नुहोस्',
'accountcreated'             => 'खाता खोलियो',
'accountcreatedtext'         => '$1 को लागी प्रयोगकर्ता खाता खोलियो ।',
'loginlanguagelabel'         => 'भाषा: $1',

# Password reset dialog
'oldpassword' => 'पुरानो पासवर्ड:',
'newpassword' => 'नयाँ पासवर्ड:',

# Edit page toolbar
'bold_sample'     => 'गाढा अक्षर',
'bold_tip'        => 'गाढा अक्षर',
'headline_sample' => 'शिर्षक अक्षर',
'math_sample'     => 'सूत्र यहाँ थप्नुहोस्',
'math_tip'        => 'गणितीय सूत्र (LaTeX)',
'nowiki_sample'   => 'यहाँ नन फर्म्याटेड ट्क्स्ट घुसाउनुहोस/लेख्नुहोस् ।',
'nowiki_tip'      => 'विकि फरम्याटिङ्लाइ वास्ता नगर्ने (इग्नोर गर्ने)',
'image_sample'    => 'उदाहरण.jpg',
'media_sample'    => 'उदाहरण.ogg',

# Edit pages
'summary'                => 'सारांश:',
'subject'                => 'विषय/शिर्षक:',
'minoredit'              => 'यो सानो सम्पादन हो',
'watchthis'              => 'यो पृष्ठ अवलोकन गर्नुहोस्',
'savearticle'            => 'संग्रह गर्नुहोस्',
'preview'                => 'पूर्वालोकन',
'showpreview'            => 'पूर्वालोकन देखाउनुहोस्',
'showlivepreview'        => 'प्रत्यक्ष पूर्वालोकन',
'showdiff'               => 'परिवर्तन देखाउनुहोस्',
'summary-preview'        => 'सारांश पूर्वालोकन:',
'blockedoriginalsource'  => "'''$1''' को स्रोत तल देखाइएको छ:",
'whitelistedittitle'     => 'सम्पादन गर्नको लागि प्रवेश (लग इन) आवश्यक छ',
'whitelistedittext'      => 'पाना सम्पादन गर्न तपाँईले $1 गर्नु पर्दछ।',
'confirmedittitle'       => 'सम्पादन गर्न इमेल पुष्टि गर्नु आवस्यक छ',
'loginreqlink'           => 'प्रवेश (लग ईन)',
'accmailtitle'           => 'पासवर्ड पठाइयो',
'accmailtext'            => '"$1" को पासवर्ड $2मा पठाइएको छ ।',
'newarticle'             => '(नयाँ)',
'note'                   => "'''सुझाव:'''",
'previewnote'            => "'''यो केवल पूर्वालोकन मात्र हो; परिवर्तनहरू संग्रह गरिसकिएको छैन!'''",
'editing'                => '$1 सम्पादन गरिँदै',
'editingsection'         => '$1 (खण्ड) सम्पादन गरिँदै',
'editconflict'           => 'सम्पादन बाँझियो: $1',
'yourtext'               => 'तपाइका शव्दहरु',
'yourdiff'               => 'भिन्नताहरु',
'template-protected'     => '(सुरक्षित)',
'template-semiprotected' => '(अर्ध-सुरक्षित)',

# Account creation failure
'cantcreateaccounttitle' => 'खाता बनाउन सकिएन',

# History pages
'viewpagelogs'     => 'यस पृष्ठका लगहरू हेर्नुहोस्',
'nohistory'        => 'यस पृष्ठको लागी कुनै सम्पादन इतिहास छैन।',
'previousrevision' => '← पुरानो संशोधन',
'nextrevision'     => 'नयाँ संशोधन →',
'next'             => 'अर्को',
'histfirst'        => 'पहिलो',
'histlast'         => 'अन्तिम',

# Diffs
'compareselectedversions' => 'छानिएका संस्करणहरू दाँज्नुहोस्',

# Search results
'notitlematches' => 'कुनैपनि पृष्ठको शिर्षक संग मिल्दैन',
'notextmatches'  => 'अक्षरस् पेज भेटिएन',
'nextn'          => 'अर्को $1',

# Preferences page
'preferences'           => 'रोजाईहरू',
'mypreferences'         => 'मेरा अभिरुचिहरू',
'prefsnologin'          => 'प्रवेश (लग ईन) नगरिएको',
'changepassword'        => 'पासवर्ड परिवर्तन गर्नुहोस्',
'skin-preview'          => 'पूर्वालोकन',
'math'                  => 'गणित',
'datetime'              => 'मिति र समय',
'math_unknown_error'    => 'अज्ञात समस्या',
'math_unknown_function' => 'अज्ञात निर्देशन',
'prefs-personal'        => 'प्रयोगकर्ताको विवरण',
'prefs-rc'              => 'नयाँ परिवर्तनहरु',
'prefs-watchlist'       => 'अवलोकन पृष्ठ',
'recentchangescount'    => 'नयाँ परिवर्तित शिर्षकहरु',
'savedprefs'            => 'तपाँईका अभिरुचिहरू सङ्ग्रहित भयो।',
'localtime'             => 'स्थानीय समय',
'allowemail'            => 'अरु प्रयोगकर्ताहरुबाट प्राप्त हुने ईमेल enable गर्नुहोस् ।',

# Groups
'group-bot' => 'बोटहरु',

'group-bot-member'   => 'बोट',
'group-sysop-member' => 'सिसप',

# Recent changes
'recentchanges'     => 'नयाँ परिवर्तनहरु',
'rclistfrom'        => '$1 देखिका नयाँ परिवर्तनहरू देखाउनु',
'diff'              => 'भिन्न',
'hist'              => 'इतिहास',
'hide'              => 'लुकाउनुहोस्',
'show'              => 'देखाउनुहोस्',
'rc_categories_any' => 'कुनै',

# Recent changes linked
'recentchangeslinked' => 'संबन्धित परिवर्तनहरु',

# Upload
'upload'            => 'फाइल अपलोड',
'uploadbtn'         => 'फाइल अपलोड गर्नु',
'uploadnologin'     => 'प्रवेश (लग ईन) नगरिएको',
'filename'          => 'फाइलनाम',
'filedesc'          => 'सारांश',
'fileuploadsummary' => 'सारांश:',
'filestatus'        => 'लेखाधिकार स्थिति:',
'filesource'        => 'स्रोत:',
'watchthisupload'   => 'यो पृष्ठ अवलोकन गर्नुहोस्',

'nolicense' => 'केहिपनि छानिएन',

# Special:ListFiles
'listfiles_date'        => 'मिति',
'listfiles_name'        => 'नाम',
'listfiles_user'        => 'प्रयोगकर्ता',
'listfiles_description' => 'वर्णन',

# File description page
'nolinkstoimage'   => 'यो फाईलसंग लिंकभएको कुनै पृष्ठ छैन.',
'noimage-linktext' => 'अपलोड गर्नुहोस्',

# MIME search
'download' => 'डाउनलोड',

# Random page
'randompage' => 'कुनै एक लेख',

# Statistics
'statistics' => 'तथ्यांक',

'brokenredirects'     => 'टुटेका रिडाइरेक्टहरू',
'brokenredirectstext' => 'तलका लिङ्कहरु ले हुदै नभएका पृष्ठहरुलाइ जोड्न खोज्छन्:',

'withoutinterwiki-summary' => 'यी पानाहरूले अन्य भाषाका संस्करणहरूमा संबन्ध राखेका छैनन्:',

# Miscellaneous special pages
'specialpage-empty' => 'यो पृष्ठ खाली छ।',
'lonelypages'       => 'अनाथ पृष्ठहरु',
'popularpages'      => 'धेरै रूचाईएका पृष्ठहरू',
'wantedpages'       => 'खोजिएका पृष्ठहरु',
'mostlinked'        => 'सबैभन्दा बढि लिंक भएको पृष्ठ',
'mostcategories'    => 'सबैभन्दा धेरै श्रेणीहरू भएका लेखहरू',
'mostimages'        => 'सबैभन्दा बढि लिंक भएको चित्र',
'mostrevisions'     => 'सबैभन्दा बढी संशोधित लेखहरू',
'shortpages'        => 'छोटा पृष्ठहरु',
'protectedpages'    => 'संरक्षित पृष्ठहरु',
'listusers'         => 'प्रयोगकर्ता सूची',
'newpages'          => 'नयाँ पृष्ठहरू',
'newpages-username' => 'युजरनेम:',
'ancientpages'      => 'सबैभन्दा पुराना पृष्ठहरु',
'move'              => 'सार्ने',
'movethispage'      => 'यो पृष्ठ सार्नुहोस्',
'notargettitle'     => 'कुनैपनि निसाना(टारगेट) छैन',

# Book sources
'booksources'               => 'किताबका श्रोतहरु',
'booksources-search-legend' => 'किताबका श्रोतहरु खोज्ने',
'booksources-go'            => 'जाउ',

# Special:Log
'specialloguserlabel'  => 'प्रयोगकर्ता:',
'speciallogtitlelabel' => 'शिर्षक:',

# Special:AllPages
'allpages'       => 'सबै पृष्ठहरु',
'alphaindexline' => '$1 लाई $2 मा',
'nextpage'       => 'अर्को पृष्ठ ($1)',
'allpagesfrom'   => 'यहाँदेखि शुरु हुने पृष्ठहरु देखाउनुहोस्:',
'allarticles'    => 'सबै लेखहरु',
'allpagesprev'   => 'अघिल्लो',
'allpagesnext'   => 'अर्को',
'allpagessubmit' => 'जानुहोस्',

# Special:Categories
'categories' => 'श्रेणीहरू',

# Special:LinkSearch
'linksearch-ns' => 'नेमस्पेस:',
'linksearch-ok' => 'खोज्नुहोस्',

# Special:ListUsers
'listusers-submit' => 'देखाउनुहोस्',

# Special:Log/newusers
'newuserlog-create-entry'  => 'नयाँ प्रयोगकर्ता',
'newuserlog-create2-entry' => '$1 का लागी खाता खोलियो',

# E-mail user
'mailnologin'     => 'ईमेल पठाउने ठेगाना नै भएन ।',
'mailnologintext' => 'तपाईले अरु प्रयोगकर्ताहरुलाई ईमेल पठाउनको लागी आफु पहिले [[Special:UserLogin|प्रवेश(लगइन)गरेको]] हुनुपर्छ र [[Special:Preferences|आफ्नो रोजाइहरुमा]] यौटा वैध ईमेल ठेगाना भएको हुनुपर्छ।',
'emailuser'       => 'यो प्रयोगकर्तालाई ई-मेल पठाउनुहोस्',
'emailpage'       => 'प्रयोगकर्तालाई इमेल गर्नुहोस्',
'noemailtitle'    => 'ईमेल ठेगाना नभएको',
'emailsubject'    => 'विषय',
'emailmessage'    => 'सन्देश',
'emailsend'       => 'पठाउनुहोस्',
'emailsent'       => 'इमेल पठाईयो',

# Watchlist
'watchlist'            => 'मेरो अवलोकन',
'mywatchlist'          => 'मेरो अवलोकनसूची',
'nowatchlist'          => 'तपाईको अवलोकन(वाचलिस्ट)मा कुनैपनि चिज छैन।',
'watchnologin'         => 'प्रवेश (लग ईन) नगरिएको',
'watchnologintext'     => 'आफ्नो अवलोकनलाइ परिवर्तन गर्नको लागि त तपाइ यसमा [[Special:UserLogin|प्रवेश(लगइन)]] गर्नुपर्छ।',
'addedwatch'           => 'अवलोकनसूची मा थपियो',
'watch'                => 'अवलोकन',
'watchthispage'        => 'यो पृष्ठ अवलोकन गर्नुहोस्',
'notanarticle'         => 'सामाग्री सहितको पेज हैन',
'wlheader-enotif'      => '* ईमेलद्वारा जानकारी गराउने तरिका enable गरियो ।',
'wlheader-showupdated' => "* तपाइले पछिल्लो पल्ट भ्रमण गरेपछि परिवर्तन भएका पृष्ठहरूलाई '''गाढा''' गरेर देखाइएको छ ।",
'wlshowlast'           => 'पछिल्ला $2 दिनहरूका $3 $1 घण्टाहरूका देखाउनुहोस्',

'enotif_newpagetext' => 'यो नयाँ पृष्ठ हो।',
'changed'            => 'परिवर्तन भइसकेको',

# Delete
'excontent'      => "लेख थियो: '$1'",
'historywarning' => 'खबरदारी: तपाईंले मेटाउन लाग्नुभएको पृष्ठको इतिहास छ:',
'actioncomplete' => 'काम सकियो',
'reverted'       => 'अघिल्लो संशोधनको स्थितिमा फर्काइयो',

# Protect
'protectlogpage'              => 'सुरक्षण लग',
'protectedarticle'            => '"[[$1]]" लाई सुरक्षित गरियो',
'prot_1movedto2'              => '[[$1]] लाई [[$2]]मा सारियो',
'protectcomment'              => 'बचाउको कारण',
'protect-default'             => '(स्वतह)',
'protect-level-autoconfirmed' => 'दर्ता नभएका प्रयोगकर्ताहरूलाई रोक',
'protect-level-sysop'         => 'सिस्अपहरू मात्र',

# Restrictions (nouns)
'restriction-edit' => 'परिवर्तन्',
'restriction-move' => 'सार्ने',

# Undelete
'viewdeletedpage' => 'मेटिएका पृष्ठहरू हेर्नुहोस्',

# Namespace form on various pages
'namespace' => 'नेमस्पेस:',

# Contributions
'contributions' => 'प्रयोगकर्ताका योगदानहरू',
'mycontris'     => 'मेरो योगदान',

# What links here
'whatlinkshere'       => 'यहाँ के जोडिन्छ',
'whatlinkshere-title' => '$1 सँग संबन्ध राख्ने पानाहरू',

# Block/unblock
'blockip'            => 'प्रयोगकर्तालाइ निषेध गर्नुहोस',
'ipaddress'          => 'आई पी ठेगाना',
'ipbotheroption'     => 'अन्य',
'ipblocklist-submit' => 'खोज्नुहोस्',
'blocklistline'      => '$1, $2 द्वारा रोकियो $3 ($4)',
'anononlyblock'      => 'anon. हरु मात्र',
'blocklink'          => 'रोक्नुहोस्',
'contribslink'       => 'योगदान',
'blocklogpage'       => 'निषेध सूची',
'proxyblocksuccess'  => 'सकियो.',

# Developer tools
'lockconfirm' => 'हो, म साँच्चिकै डेटाबेस थुन्न चाहन्छु।',
'lockbtn'     => 'डेटाबेस थुनिदिनुस्',
'unlockbtn'   => 'डाटाबेस अनलक गर्नुहोस्',

# Move page
'move-page-legend'        => 'पृष्ठ सार्नुहोस्',
'movearticle'             => 'पृष्ठ सार्नुहोस्',
'movenologin'             => 'प्रवेश (लग ईन) नगरिएको',
'movepagebtn'             => 'पृष्ठ सार्नुहोस्',
'pagemovedsub'            => 'सार्ने काम सफल भयो',
'movedto'                 => 'मा सारियो',
'1movedto2'               => '[[$1]] लाई [[$2]]मा सारियो',
'movereason'              => 'कारण',
'delete_and_move_confirm' => 'हो, पृष्ठ मेट्नुहोस्',

# Namespace 8 related
'allmessages'         => 'सिस्टम सन्देशहरू',
'allmessagesname'     => 'नाम',
'allmessagestext'     => 'यो मिडियाविकि नेमस्पेसमा पाइने सिस्टम सन्देशहरूको सूची हो।',
'allmessagesmodified' => 'परिवर्तित मात्र देखाउनुहोस्',

# Special:Import
'import'                  => 'पृष्ठहरु आयात गर्नुहोस्',
'import-interwiki-submit' => 'आयात',
'importstart'             => 'पृष्ठ आयात गरिँदै...',
'importsuccess'           => 'आयात सम्पन्न भयो!',

# Tooltip help for the actions
'tooltip-pt-userpage'     => 'मेरो प्रयोगकर्ता पृष्ठ',
'tooltip-pt-mytalk'       => 'मेरो वार्तालाप पृष्ठ',
'tooltip-pt-preferences'  => 'मेरा अभिरुचिहरू (प्रेफरेन्सेस्‌हरू)',
'tooltip-pt-watchlist'    => 'पृष्ठहरूको सूची जसका परिवर्तनहरूलाई तपाईँले निगरानी गरिरहनु भएको छ',
'tooltip-pt-mycontris'    => 'मेरा योगदानहरूको सूची',
'tooltip-pt-anonlogin'    => 'तपाईँलाई लग-इन गर्न प्रोत्साहन गरिन्छ, तर यो अनिवार्य चाँही होइन।',
'tooltip-pt-logout'       => 'निर्गमन (लग आउट) गर्नुहोस्',
'tooltip-ca-viewsource'   => 'यो पृष्ठ सुरक्षित गरिएको छ। यसको श्रोत हेर्न सक्नुहुन्छ।',
'tooltip-ca-protect'      => 'यो पृष्ठलाई संरक्षित गर्नुहोस्',
'tooltip-ca-delete'       => 'यो पृष्ठ मेटाउनुहोस्',
'tooltip-ca-move'         => 'यो पृष्ठलाई सार्नुहोस्',
'tooltip-ca-watch'        => 'यो पृष्ठलाई तपाईँको अवलोकनसूचीमा थप्नुहोस्',
'tooltip-ca-unwatch'      => 'यो पृष्ठलाई तपाईँको अवलोकनसूचीबाट हटाउनुहोस्',
'tooltip-search'          => '{{SITENAME}} मा खोज्नुहोस्',
'tooltip-p-logo'          => 'मुख्य पृष्ठ',
'tooltip-t-contributions' => 'यस प्रयोगकर्ताका योगदानहरूको सूची हेर्नुहोस्',
'tooltip-t-specialpages'  => 'सबै विशेष पृष्ठहरूको सूची',
'tooltip-save'            => 'तपाईँले गरेका परिवर्तनहरू संग्रह (सेभ) गर्नुहोस्',
'tooltip-watch'           => 'यो पृष्ठलाई तपाईँको अवलोकनसूचीमा थप्नुहोस्',

# Attribution
'lastmodifiedatby' => 'यो पृष्ठ अन्तिमपटक $3द्वारा $2, $1 मा परिवर्तन गरिएको थियो।', # $1 date, $2 time, $3 user
'othercontribs'    => '$1 को कामको आधारमा',
'others'           => 'अन्य',

# Info page
'infosubtitle'   => 'पृष्ठको लागि जानकारी',
'numedits'       => 'सम्पादन संख्या (लेख): $1',
'numtalkedits'   => 'सम्पादन संख्या (छलफल पृष्ठ): $1',
'numwatchers'    => 'अवलोकन संख्या: $1',
'numauthors'     => 'प्रष्ट लेखकहरुको संख्या (लेख): $1',
'numtalkauthors' => 'लेखकहरूको संख्या (छलफल पृष्ठ): $1',

# Patrol log
'patrol-log-auto' => '(स्वचालित)',

# Browsing diffs
'previousdiff' => '← अधिल्लो भिन्नता',
'nextdiff'     => 'पछिल्लो भिन्नता →',

# Special:NewFiles
'noimages' => 'हेर्नको लागि केही छैन.',
'ilsubmit' => 'खोज्नुहोस्',
'bydate'   => 'मिति अनुसार',

# Metadata
'metadata'          => 'मेटाडेटा',
'metadata-expand'   => 'लामो विबरण देखाउनुहोस्',
'metadata-collapse' => 'लामो विबरण लुकाउनुहोस्',

# EXIF tags
'exif-imagewidth'                => 'चौडाइ',
'exif-photometricinterpretation' => 'पिक्सेल कम्पोजिसन',
'exif-imagedescription'          => 'चित्र नाम',
'exif-make'                      => 'क्यामेरा निर्माता',
'exif-artist'                    => 'लेखक',
'exif-lightsource'               => 'प्रकाश स्रोत',
'exif-subjectarea'               => 'विषय क्षेत्र',
'exif-filesource'                => 'फाइल स्रोत',
'exif-gpslatituderef'            => 'उत्तर वा दक्षिण अक्षांश',
'exif-gpslatitude'               => 'अक्षांश',
'exif-gpslongituderef'           => 'पूर्व वा पश्चिम देशान्तर',
'exif-gpslongitude'              => 'देशान्तर',
'exif-gpsaltitude'               => 'उँचाई',
'exif-gpsstatus'                 => 'रिसिभर अवस्था',
'exif-gpstrack'                  => 'चलेको दिशा',

'exif-orientation-1' => 'सामान्य', # 0th row: top; 0th column: left
'exif-orientation-6' => '90° CW घुमाइएको', # 0th row: right; 0th column: top

'exif-subjectdistance-value' => '$1 मिटर',

'exif-meteringmode-0'   => 'अज्ञात',
'exif-meteringmode-1'   => 'सामान्य',
'exif-meteringmode-255' => 'अन्य',

'exif-lightsource-0' => 'अज्ञात',

'exif-focalplaneresolutionunit-2' => 'इञ्च',

'exif-customrendered-0' => 'सामान्य प्रक्रिया',

'exif-contrast-0' => 'सामान्य',
'exif-contrast-1' => 'हल्का',
'exif-contrast-2' => 'गाढा',

# Pseudotags used for GPSLatitudeRef and GPSDestLatitudeRef
'exif-gpslatitude-n' => 'उत्तर अक्षांश',
'exif-gpslatitude-s' => 'दक्षिण अक्षांश',

# Pseudotags used for GPSLongitudeRef and GPSDestLongitudeRef
'exif-gpslongitude-e' => 'पूर्व देशान्तर',
'exif-gpslongitude-w' => 'पश्चिम देशान्तर',

# Pseudotags used for GPSSpeedRef and GPSDestDistanceRef
'exif-gpsspeed-k' => 'किलोमिटर प्रति घण्टा',
'exif-gpsspeed-m' => 'माइल प्रति घण्टा',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'सबै',
'imagelistall'     => 'सबै',
'watchlistall2'    => 'सबै',
'namespacesall'    => 'सबै',

# E-mail address confirmation
'confirmemail' => 'इमेल ठेगाना पक्का गर्नुहोस्',

# Delete conflict
'recreate' => 'पुनर्निर्माण',

# action=purge
'confirm_purge_button' => 'हुन्छ',

# Multipage image navigation
'imgmultipageprev' => '← अघिल्लो पृष्ठ',
'imgmultipagenext' => 'पछिल्लो पृष्ठ →',
'imgmultigo'       => 'जानुहोस्!',

# Table pager
'ascending_abbrev'         => 'वर्णानुक्रम',
'table_pager_next'         => 'पछिको पृष्ठ',
'table_pager_prev'         => 'अगाडिको पृष्ठ',
'table_pager_first'        => 'प्रथम पृष्ठ',
'table_pager_last'         => 'अन्तिम पृष्ठ',
'table_pager_limit_submit' => 'जाउ',

# Auto-summaries
'autosumm-blank'   => 'पृष्ठको सबै सामाग्रीहरू हटाइ पृष्ठ खाली गरीँदै',
'autosumm-replace' => "पृष्ठलाई '$1' संग हटाइदै",
'autosumm-new'     => 'नयाँ पृष्ठ: $1',

# Live preview
'livepreview-loading' => 'लोड गरिंदै छ…',

# Special:FilePath
'filepath-page' => 'फाइल',

# Special:SpecialPages
'specialpages' => 'विशेष पृष्ठ',

);
